..
    This file is part of Invenio.
    Copyright (C) 2016-2019 CERN.

    Invenio is free software; you can redistribute it and/or modify it
    under the terms of the MIT License; see LICENSE file for more details.



Changes
=======

Version 1.3.2 (Release 2020-12-11)
------------------------------------

- Fixes the preview button and the question icon mark in the Jinja macro.

Version 1.3.1 (Release 2020-12-11)
------------------------------------

- Fixes the file download link the Jinja macro for listing files.

Version 1.3.0 (Release 2020-12-10)
------------------------------------

- Migration to Semantic-UI.
- Drops support of flask-assets.
- Fixes PDF.js static asset paths.
- Migrate CI to GitHub Actions.
- Fixes imports in Bootstrap and Semantic UI files.

Version 1.2.1 (Release 2020-05-07)
----------------------------------

- set Sphinx ``<3`` because of errors related to application context
- stop using example app

Version 1.2.0 (Release 2020-03-13)
----------------------------------

- Change flask dependency to centrally managed by invenio-base
- Drop support for Python 2.7

Version 1.1.0 (Release 2019-12-20)
----------------------------------

- Changes styling and method signature of file_list macro.

Version 1.0.2 (Release 2019-11-21)
----------------------------------

- Removes inline styling from simple image previewer for Content Security
  Policy compliance

Version 1.0.1 (Release 2019-08-02)
----------------------------------

- Removes html sanitization config

Version 1.0.0 (release 2019-07-29)
----------------------------------

- Initial public release.
